==> org.eclipse.app4mc.amalthea.converters.071.source_0.7.2.201701261220.jar: org/eclipse/app4mc/amalthea/converters071/impl/PropertyConstraintsConverter.java <==
/*******************************************************************************
 * Copyright (c) 2016 Robert Bosch GmbH and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Robert Bosch GmbH - initial API and implementation
 *******************************************************************************/
package org.eclipse.app4mc.amalthea.converters071.impl;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.apache.log4j.LogManager;
import org.eclipse.app4mc.amalthea.converters.common.base.ICache;
import org.eclipse.app4mc.amalthea.converters071.utils.HelperUtils_070_071;
import org.jdom2.Document;
import org.jdom2.Element;

public class PropertyConstraintsConverter extends AbstractConverter {


	public PropertyConstraintsConverter() {
		this.helper = HelperUtils_070_071.getInstance();
		this.logger = LogManager.getLogger(this.getClass());
	}

	@Override
	public void convert(final File targetFile, final Map<File, Document> fileName_documentsMap,
			final List<ICache> caches) throws Exception {

		this.logger.info("Migration from 0.7.0 to 0.7.1 : Starting PropertyConstraints converter");

		final Document root = fileName_documentsMap.get(targetFile);

		if (root == null) {
			return;
		}
		final Element rootElement = root.getRootElement();

		/*- Migration of size attribute of MemoryType to DataSize element */

		update_Size_MemoryType(rootElement, "./propertyConstraintsModel/memoryTypeDefinitions");

		/*- Migration of frequency attribute of Quartz to Frequency element */

		update_frequency_Quartz(rootElement,
				"./propertyConstraintsModel/mappingConstraints/hwConstraint//quartzes[@frequency]");

		fileName_documentsMap.put(targetFile.getCanonicalFile(), root);
	}


}

==> org.eclipse.app4mc.amalthea.converters.071.source_0.8.2.201708030634.jar: org/eclipse/app4mc/amalthea/converters071/impl/PropertyConstraintsConverter.java <==
/*******************************************************************************
 * Copyright (c) 2016 Robert Bosch GmbH and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Robert Bosch GmbH - initial API and implementation
 *******************************************************************************/
package org.eclipse.app4mc.amalthea.converters071.impl;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.apache.log4j.LogManager;
import org.eclipse.app4mc.amalthea.converters.common.base.ICache;
import org.eclipse.app4mc.amalthea.converters071.utils.HelperUtils_070_071;
import org.jdom2.Document;
import org.jdom2.Element;

public class PropertyConstraintsConverter extends AbstractConverter {


	public PropertyConstraintsConverter() {
		this.helper = HelperUtils_070_071.getInstance();
		this.logger = LogManager.getLogger("org.eclipse.app4mc.amalthea.modelmigration");
	}

	@Override
	public void convert(final File targetFile, final Map<File, Document> fileName_documentsMap,
			final List<ICache> caches) throws Exception {

		this.logger.info("Migration from 0.7.0 to 0.7.1 : Executing PropertyConstraints converter for model file : "
				+ targetFile.getName());

		final Document root = fileName_documentsMap.get(targetFile);

		if (root == null) {
			return;
		}
		final Element rootElement = root.getRootElement();

		/*- Migration of size attribute of MemoryType to DataSize element */

		update_Size_MemoryType(rootElement, "./propertyConstraintsModel/memoryTypeDefinitions");

		/*- Migration of frequency attribute of Quartz to Frequency element */

		update_frequency_Quartz(rootElement,
				"./propertyConstraintsModel/mappingConstraints/hwConstraint//quartzes[@frequency]");

		fileName_documentsMap.put(targetFile.getCanonicalFile(), root);
	}


}
